function [TalphaPlus]= unmixing(y,MPlus,Nmc)

%------------------------------------------------------------------
% LINEAR SPECTRAL UNMIXING
% by N. DOBIGEON and J.-Y. TOURNERET 
% IRIT/ENSEEIHT/TSA - France - 2007
% 
% INPUT
%       y        : the pixel to be unmixed
%       MPlus    : the spectra used in the mixture
%       Nmc      : number of MCMC iterations
%
% OUTPUT
%       TalphaPlus : the samples \alpha^+ generated by the procedure
%
%------------------------------------------------------------------


% number of spectral bands x number of endmember spectra
[L R] = size(MPlus);

% initialization of the parameters
sigma2 = 1;
alphaPlus = ones(R,1)/R;


TalphaPlus = zeros(R,Nmc);

% useful quantities
u = ones(R-1,1);
M = MPlus(:,1:(R-1));
mr = MPlus(:,R);
invT = inv((M-mr*u')'*(M-mr*u'));

h = waitbar(0,'Sampling...','CreateCancelBtn','closereq', 'name', 'UNMIXING...');

% beginning
for m_compt=1:Nmc
    
    waitbar(m_compt/Nmc,h)
            
    % updating the abundance coefficients
    alphaPlus = sample_alphaPlus(alphaPlus,y,invT,MPlus,sigma2);    
    TalphaPlus(:,m_compt) = alphaPlus;
    
    % updating the noise variance
    sigma2 = sample_sigma2(L,y,MPlus,R,alphaPlus);
    
end
close(h)
    