function result = exploitation(TalphaPlus,Nbi,Nmc)

%------------------------------------------------------------------
% This function allows to exploit the results provided by
%       the function unmixing
% 
% INPUT
%       TalphaPlus : The MCMC samples alphaPlusgenerated by the Gibbs sampling
%       Nbi   : number of burn-in iterations
%       Nmc   : length of the Markov Chain
%
% OUTPUT
%       result : 1 if the function is correctly used, 0 otherwise
%
%------------------------------------------------------------------

Nr = Nmc - Nbi;

R = size(TalphaPlus,1);

figure

for i=1:R
    Talphai = TalphaPlus(i,Nbi+1:end);
    xmin = min(Talphai)*0.8;
    xmax = max(Talphai)*1.2;
    Nc = sqrt(Nmc-Nbi+1);
    pas = (xmax-xmin)/Nc;
    hi = hist(Talphai,xmin:pas:xmax);
    hi = hi/(pas*Nr);
    subplot(1,R,i)
    plot(xmin:pas:xmax,hi)
    set(gca,'ytick',[]);
    axis([xmin xmax 0 max(hi)*1.1]);
    ylabel(['Posterior distribution of \alpha_' int2str(i)]);
end

result = 1;
